@@ -52,17 +52,19 @@ pub fn clear_and_show(dir: &Path) {
 
     let git = dir.join(".git");
     if git.exists() {
-        let head = std::fs::read(".git/HEAD").unwrap();
-        let branch: Vec<u8> = head.into_iter().skip(16).collect();
-        let branch = std::str::from_utf8(&branch).unwrap();
-        print!(
-            " on {}{}{}{}{}",
-            style::Bold,
-            color::Fg(color::Magenta),
-            branch,
-            style::Reset,
-            color::Fg(color::Reset)
-        );
+        let head = git.join("HEAD");
+        if let Ok(head) = std::fs::read(head) {
+            let branch: Vec<u8> = head.into_iter().skip(16).collect();
+            let branch = std::str::from_utf8(&branch).unwrap();
+            print!(
+                " on {}{}{}{}{}",
+                style::Bold,
+                color::Fg(color::Magenta),
+                branch,
+                style::Reset,
+                color::Fg(color::Reset)
+            );
+        }
     }
     //Show arrow
     print!("{}{}", cursor::Goto(2, 2), DOWN_ARROW);
